@@ -1,6 +1,7 @@
 package template
 
 import (
+	"path/filepath"
 	"text/template"
 
 	"github.com/Masterminds/sprig/v3"
@@ -10,7 +11,7 @@ func funcMap() template.FuncMap {
 	funcMap := map[string]any{
 		"secondsRound": secondsRound,
 		"url":          url,
-		"path":         path,
+		"path":         filePath,
 		"glob":         glob,
 		"matchP":       matchP,
 		"replaceP":     replaceP,
@@ -20,11 +21,16 @@ func funcMap() template.FuncMap {
 		"hresult":      hresult,
 		"trunc":        trunc,
 		"readFile":     readFile,
+		"stat":         stat,
+		"dir":          filepath.Dir,
+		"base":         filepath.Base,
 	}
+
 	for key, fun := range sprig.TxtFuncMap() {
 		if _, ok := funcMap[key]; !ok {
 			funcMap[key] = fun
 		}
 	}
+
 	return template.FuncMap(funcMap)
 }
