@@ -18,6 +18,11 @@ module.exports = {
     "https://fonts.googleapis.com/css2?family=Fira+Code&display=swap"
   ],
   themeConfig: {
+    colorMode: {
+      defaultMode: 'light',
+      disableSwitch: false,
+      respectPrefersColorScheme: true,
+    },
     prism: {
       additionalLanguages: ['powershell', 'lua', 'jsstacktrace', 'toml', 'json', 'yaml'],
     },
@@ -163,6 +168,9 @@ module.exports = {
             require.resolve('./src/css/custom.css')
           ],
         },
+        blog: {
+          onInlineAuthors: 'ignore'
+        },
       },
     ],
   ],
